[pkg-opensc-commit] [libp11] 65/239: we need to free the ex_data as well

Eric Dorland eric at moszumanska.debian.org
Sat Oct 17 06:21:09 UTC 2015


This is an automated email from the git hooks/post-receive script.

eric pushed a commit to branch master
in repository libp11.

commit fdab0c1db03203c1e9a2b5d34750329521188ca7
Author: Nils Larsch <nlarsch at gmx.net>
Date:   Sat Oct 22 12:07:55 2005 +0000

    we need to free the ex_data as well
---
 examples/decrypt.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/examples/decrypt.c b/examples/decrypt.c
index 74a46b9..16745a4 100644
--- a/examples/decrypt.c
+++ b/examples/decrypt.c
@@ -184,7 +184,7 @@ int main(int argc, char *argv[])
 		goto failed;
 	}
 
 	/* allocate space for decrypted. */
 	decrypted = malloc(RSA_size(pubkey->pkey.rsa));
 	if (!decrypted)
 		goto failed;
@@ -215,6 +215,7 @@ int main(int argc, char *argv[])
 	if (decrypted != NULL)
 		free(decrypted);
 
+	CRYPTO_cleanup_all_ex_data();
 	ERR_free_strings();
 	ERR_remove_state(0);
 
@@ -184,7 +184,7 @@ int main(int argc, char *argv[])
 	}
 
-	/* allocate space for decrypted. */
+	/* allocate space for decrypted data */
 	decrypted = malloc(RSA_size(pubkey->pkey.rsa));
 	if (!decrypted)

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-opensc/libp11.git



More information about the pkg-opensc-commit mailing list